Effektive Verwaltung Ihrer IBM Cloud Supportfälle

Erfahren Sie, wie Sie Ihre IBM Cloud Supportfälle verwalten, einschließlich der Verfolgung des Fortschritts, der Aktualisierung von Fällen und der Verwaltung von Beobachtungslisten für eine effektive Problemlösung.

Rufen Sie die Seite Fälle verwalten auf, um Supportfälle anzuzeigen und zu verwalten. Wenn Sie ein Benutzer der klassischen Infrastruktur sind und ein vorheriger Fall nicht in der Liste aufgeführt wird, klicken Sie auf Fälle der klassischen Infrastruktur anzeigen. Sie können auch einen schnellen Überblick über Ihre 5 zuletzt aktualisierten offenen Fälle erhalten, indem Sie case status in den IBM Cloud KI-Assistenten eingeben.

Sie können Ihre IBM Supportfälle auch auf der Seite "Fälle verwalten" einsehen, aber sie können nur im IBM Supportportal verwaltet werden. Der Zugriff auf diese Fälle wird über das Support-Portal IBM gesteuert. Weitere Informationen zum Zugriff finden Sie unter Verwalten des Zugriffs auf Ihr Support-Konto.

Supportfälle über die API anzeigen

Sie können einen Supportfall programmgesteuert anzeigen, indem Sie die API verwenden, wie in der folgenden Beispielanforderung dargestellt. Weitere Informationen finden Sie in der Case Management-API.

Die folgenden Beispiele veranschaulichen das Anzeigen eines Falls:

curl -X GET 'https://support-center.cloud.ibm.com/case-management/v1/cases/{case_number}?fields=number,updated_at,resources' -H 'Authorization: TOKEN' \
GetCaseOptions getCaseOptions = new GetCaseOptions.Builder()
  .caseNumber(caseNumber)
  .addFields(GetCaseOptions.Fields.DESCRIPTION)
  .addFields(GetCaseOptions.Fields.STATUS)
  .addFields(GetCaseOptions.Fields.SEVERITY)
  .addFields(GetCaseOptions.Fields.CREATED_BY)
  .build();
Response<Case> response = service.getCase(getCaseOptions).execute();
Case xCase = response.getResult();
System.out.println(xCase);
const fieldsToReturn = [
  CaseManagementV1.GetCaseConstants.Fields.DESCRIPTION,
  CaseManagementV1.GetCaseConstants.Fields.STATUS,
  CaseManagementV1.GetCaseConstants.Fields.SEVERITY,
  CaseManagementV1.GetCaseConstants.Fields.CREATED_BY,
];
const params = {
  caseNumber: caseNumber,
  fields: fieldsToReturn,
};
caseManagementService.getCase(params)
  .then(res => {
    console.log(JSON.stringify(res.result, null, 2));
  })
  .catch(err => {
    console.warn(err)
  });
fields_to_return = [
  GetCaseEnums.Fields.DESCRIPTION,
  GetCaseEnums.Fields.STATUS,
  GetCaseEnums.Fields.SEVERITY,
  GetCaseEnums.Fields.CREATED_BY,
]
case = case_management_service.get_case(
  case_number=case_number,
  fields=fields_to_return
).get_result()
print(json.dumps(case, indent=2))
getCaseOptions := caseManagementService.NewGetCaseOptions(
  caseNumber,
)
getCaseOptions.SetFields([]string{
  casemanagementv1.GetCaseOptionsFieldsDescriptionConst,
  casemanagementv1.GetCaseOptionsFieldsStatusConst,
  casemanagementv1.GetCaseOptionsFieldsSeverityConst,
  casemanagementv1.GetCaseOptionsFieldsCreatedByConst,
})
caseVar, response, err := caseManagementService.GetCase(getCaseOptions)
if err != nil {
  panic(err)
}
b, _ := json.MarshalIndent(caseVar, "", "  ")
fmt.Println(string(b))

Supportfälle über die API aktualisieren

Die folgende Beispielanforderung zeigt, wie ein Supportfall programmgesteuert aktualisiert wird. Weitere Informationen finden Sie in der Case Management-API.

curl -X PUT '/case-management/v1/cases/{case_number}/status' -H 'Authorization: TOKEN' -d '{
  "action": "resolve",
  "comment": "The issue is resolved. Thank you!",
  "resolution_code": 1
}'
ResolvePayload statusPayloadModel = new ResolvePayload.Builder()
  .action("resolve")
  .comment("The problem has been resolved.")
  .resolutionCode(1)
  .build();
UpdateCaseStatusOptions updateCaseStatusOptions = new UpdateCaseStatusOptions.Builder()
  .caseNumber(caseNumber)
  .statusPayload(statusPayloadModel)
  .build();
Response<Case> response = service.updateCaseStatus(updateCaseStatusOptions).execute();
Case xCase = response.getResult();
System.out.println(xCase);
const statusPayloadModel = {
  action: 'resolve',
  comment: 'The problem has been resolved.',
  resolution_code: 1,
};
const params = {
  caseNumber: caseNumber,
  statusPayload: statusPayloadModel,
};
caseManagementService.updateCaseStatus(params)
  .then(res => {
    console.log(JSON.stringify(res.result, null, 2));
  })
  .catch(err => {
    console.warn(err)
  });
status_payload_model = {
  'action': 'resolve',
  'comment': 'The problem has been resolved.',
  'resolution_code': 1,
}
case = case_management_service.update_case_status(
  case_number=case_number,
  status_payload=status_payload_model
).get_result()
print(json.dumps(case, indent=2))
statusPayloadModel := &casemanagementv1.ResolvePayload{
  Action:         core.StringPtr("resolve"),
  Comment:        core.StringPtr("The problem has been resolved."),
  ResolutionCode: core.Int64Ptr(int64(1)),
}
updateCaseStatusOptions := caseManagementService.NewUpdateCaseStatusOptions(
  caseNumber,
  statusPayloadModel,
)
caseVar, response, err := caseManagementService.UpdateCaseStatus(updateCaseStatusOptions)
if err != nil {
  panic(err)
}
b, _ := json.MarshalIndent(caseVar, "", "  ")
fmt.Println(string(b))

Kommentare zu Supportfällen über die API hinzufügen

Die folgende Beispielanforderung zeigt, wie ein Kommentar programmgesteuert zu einem Supportfall hinzugefügt werden kann. Weitere Informationen finden Sie in der Case Management-API.

curl -X PUT '/case-management/v1/cases/{case_number}/comments' -H 'Authorization: TOKEN' -d '{
  "comment": "Test comment api"
}'
AddCommentOptions addCommentOptions = new AddCommentOptions.Builder()
  .caseNumber(caseNumber)
  .comment("This is an example comment.")
  .build();
Response<Comment> response = service.addComment(addCommentOptions).execute();
Comment comment = response.getResult();
System.out.println(comment);
const params = {
  caseNumber: caseNumber,
  comment: 'This is an example comment,',
};
caseManagementService.addComment(params)
  .then(res => {
    console.log(JSON.stringify(res.result, null, 2));
  })
  .catch(err => {
    console.warn(err)
  });
comment = case_management_service.add_comment(
  case_number=case_number,
  comment='This is an example comment.'
).get_result()
print(json.dumps(comment, indent=2))
addCommentOptions := caseManagementService.NewAddCommentOptions(
  caseNumber,
  "This is an example comment.",
)
comment, response, err := caseManagementService.AddComment(addCommentOptions)
if err != nil {
  panic(err)
}
b, _ := json.MarshalIndent(comment, "", "  ")
fmt.Println(string(b))

Aktualisierung von Supportfällen

Wählen Sie die Fallnummer aus, um den Supportfall zu aktualisieren. Sie können einen Kommentar hinzufügen, Dateien anhängen oder entfernen, Ressourcen hinzufügen oder die Beobachtungsliste aktualisieren. Führen Sie die folgenden Schritte aus, um Ihren Supportfall zu aktualisieren:

  1. Klicken Sie in der Menüleiste der Konsole IBM Cloud auf das Hilfesymbol Hilfe > Support Center.
  2. Wählen Sie den Supportfall aus der Kachel Zuletzt aufgerufene Supportfälle aus.
  3. Fügen Sie einen Kommentar hinzu und klicken Sie dann auf Senden.
  4. Optional können Sie die folgenden Felder aktualisieren:
    • Einen Benutzer zur Beobachtungsliste hinzufügen
    • Anhängen oder Entfernen von Dateien
    • Hinzufügen einer spezifischen Ressource für einen technischen Supportfall

Hinzufügen einer CRN zu einem Fallkommentar

Das Hinzufügen von Details zu den spezifischen Ressourcen im Zusammenhang mit einem Supportfall ermöglicht eine effizientere Triage, Untersuchung und Lösung. Führen Sie die folgenden Schritte aus, um einen Cloud-Ressourcennamen (CRN) anzuzeigen und zu kopieren, um ihn einem Supportfall hinzuzufügen:

  1. Klicken Sie in der IBM Cloud® Konsole auf das Symbol für das Navigationsmenü > Navigationsmenü-Symbol, Ressourcenliste um Ihre Ressourcenliste anzuzeigen.
  2. Erweitern Sie die Abschnitte, um die Dienstinstanz zu finden, für die Sie die CRN abrufen möchten.
  3. Klicken Sie auf die Tabellenzeile. Diese Aktion öffnet das Seitenfenster der Ressourcentabelle, in dem Sie die CRN einsehen können.
  4. Wählen Sie in die Zwischenablage kopieren neben dem CRN-Wert.
  5. Fügen Sie den Wert in einen Kommentar im Supportfall ein.

Beobachtungsliste eines Supportfalls aktualisieren

Die Benutzer, die in Ihrem Konto Benachrichtigungen zu Ihrem Supportfall erhalten können, können Sie aktualisieren, indem Sie sie zur Beobachtungsliste hinzufügen. Benutzer können beim Erstellen von Supportfällen oder nach der Erstellung des Supportfalls zur Beobachtungsliste hinzugefügt werden.

Standardmäßig verfügen Kontobenutzer nicht über die Zugriffsberechtigung zum Erstellen, Aktualisieren, Durchsuchen oder Anzeigen von Fällen. Der Kontoinhaber muss den Benutzern Zugriff gewähren, indem er eine IAM-Zugriffsrichtlinie ( Identity and Access Management ) zuweist. Weitere Informationen finden Sie in Benutzerzugriff für die Arbeit mit Supportfällen zuweisen.

Um sicherzustellen, dass Benutzer über Aktualisierungen für einen vorhandenen Supportfall benachrichtigt werden, den Sie erstellt haben, fügen Sie sie mit den folgenden Schritten zur Beobachtungsliste hinzu.

  1. Klicken Sie in der Menüleiste der Konsole IBM Cloud auf das Hilfesymbol Hilfe > Support Center.

  2. Wählen Sie den Supportfall aus der Kachel Zuletzt aufgerufene Supportfälle aus.

  3. Klicken Sie im Bereich Beobachtungsliste auf das Symbol Einstellungen

  4. Wählen Sie Benutzer im Konto aus, die zur Beobachtungsliste hinzugefügt werden sollen.

    Benutzer, die zur Beobachtungsliste hinzugefügt werden, müssen ein Mitglied des Kontos sein, in dem der Fall erstellt wurde. Weitere Informationen darüber, wie Sie Benutzern eine Zugriffsberechtigung für Ihr Konto zuweisen, finden Sie unter Benutzer zur Zugriffsgruppe für das Fallmanagement hinzufügen.

Statustypen für Supportfälle

Wenn Ihre Antwort auf eine Aktualisierung Ihres Supportfalls erforderlich ist, wird der Status Waiting on client angezeigt. Wenn Sie nicht innerhalb von sieben Tagen antworten, wird der Status in Resolved aktualisiert. Liegt nach weiteren sieben Tagen weiterhin keine Antwort vor, wird der Fall geschlossen. Eine Beschreibung der einzelnen Statustypen finden Sie in der folgenden Tabelle:

Statustypen für Supportfälle
Status Beschreibung
Neu Ein Fall wurde erstellt, aber noch nicht durch einen Supportmitarbeiter geprüft.
In Bearbeitung Der Fall wird geprüft.
Warten auf Kunden Der Support-Mitarbeiter hat eine Anfrage zu dem Fall eingereicht, die eine Antwort des Benutzers erfordert.
Lösung bereitgestellt Der Supportmitarbeiter hat eine Lösung bereitgestellt, die der Benutzer ausführen muss.
Behoben Der Supportfall wird als beendet eingestuft und ist für den Abschluss bereit.
Geschlossen Der Fall wurde durch einen Supportmitarbeiter geschlossen und kann nicht erneut geöffnet werden.

Supportfälle eskalieren

Mit einem kostenpflichtigen Support-Vertrag können Sie den Eskalationsprozess nutzen, um kritische Probleme zu melden und Ihre Bedenken bezüglich eines Supportfalls zu äußern. Bei Eskalation eines Falls prüft das IBM Cloud-Support-Team die Informationen im Supportfall und informiert den Kunden über entsprechende Updates. Informationen zu Fallprioritäten finden Sie in Fallpriorität und Erstreaktionszeiten.

Führen Sie die folgenden Schritte aus, um einen Fall zu eskalieren:

  1. Kontaktieren Sie den IBM Cloud Support per Chat oder Telefon.
    • Klicken Sie im Support Center auf KI-Assistent starten und geben Sie agent ein, um eine Verbindung mit einem Support-Mitarbeiter herzustellen
    • Rufen Sie unter der im Support Center angegebenen Nummer an.
  2. Geben Sie Ihre Fallnummer und Anforderung an, um den Fall zu eskalieren.
  3. Geben Sie die Begründung für eine Eskalation an und erläutern Sie den Einfluss des Problems oder Fehlers auf die Geschäftsabläufe.

Basis-Supportpläne: Wenn Sie einen Basis-Supportplan haben, erhalten Sie nur in nichttechnischen Fällen Zugang zum Support. Wenn Ihre Support-Anfrage eine sofortige Antwort erfordert, sollten Sie ein Upgrade auf einen Premium- oder Advanced-Supportplan in Betracht ziehen, damit Sie einem Fall einen Schweregrad zuweisen können. Um Ihr Support-Paket zu erweitern, erstellen Sie bitte einen Fall im Support-Center oder wenden Sie sich an einen Vertriebsmitarbeiter von IBM Cloud, um Unterstützung zu erhalten.

Supportfälle suchen

Auf der Seite Fälle verwalten können Sie nach Fallstatus filtern und mithilfe von Suchparametern in der Suchleiste nach all Ihren Supportfällen suchen. Die Standardfilter sind so eingestellt, dass nur offene Fälle angezeigt werden. Um gelöste oder geschlossene Fälle anzuzeigen, passen Sie den Statusfilter an. Alle Parameter können zusammen verwendet und in beliebiger Reihenfolge eingegeben werden. Sie können die Fälle auch filtern, indem Sie Alle Fälle, Meine Fälle und Watchlist-Fälle auswählen.

Die folgende Tabelle enthält Details zu den Suchparametern:

Suchabfrageparameter und -optionen
Parameter Option Regel
number Zielfallnummer Dieser Parameter kann nicht zusammen mit anderen Parametern verwendet werden. Wenn der Parameter number verwendet wird, werden alle anderen Parameter und Optionen ignoriert. Bei der Verwendung des Parameters number erfolgt kein automatisches Füllen des Suchfelds. Zum Starten der Suche müssen Sie die vollständige Fallnummer verwenden.
sort Nummer
Betreff
Priorität
AktualisiertAm
Es kann nur jeweils eine der sort-Optionen verwendet werden. Sie können das Präfix ~ angeben, um die Sortierreihenfolge umzukehren.
status Neu
InBearbeitung
WartenAufKunden
LösungBereitgestellt
Gelöst
Geschlossen
Es können beliebig viele Optionen verwendet werden. Die verfügbaren Optionen können als status:new,inProgress oder status:new status:inProgress eingegeben werden.
page anzuzeigende Zielseite Wenn die Suche mehrere Ergebnisse liefert, die mehrere Seiten umfassen, können Sie Ihre Ergebnisse auf jeder beliebigen Ergebnisseite anzeigen. Beispiel: Zum Anzeigen der Seite 5 von insgesamt 10 Seiten verwenden Sie page:5.
pageSize 10
25
50
100
Die Größe der anzuzeigenden Seite. Die Seitengröße bezieht sich auf die Anzahl der Ergebnisse, die geladen werden sollen.

Wenn ein Begriff ohne Parameter eingegeben wird, werden die Suchergebnisse für die Supportfallnummer und das Subjekt des Falls angezeigt.

Beispiele für Abfragen und URLs

Sie können Suchanfragen in die Suchleiste eingeben, indem Sie einen Parameter und eine Option durch einen Doppelpunkt (:) getrennt angeben, oder Sie können Parameter in einem URL verwenden, um direkt zu einem bestimmten Fall oder einer Gruppe von Fällen auf der Seite „Fälle verwalten“ zu gelangen.

Um Parameter in der Befehlszeile URL zu verwenden, fügen Sie am Ende des Befehls URL ein Fragezeichen (?) hinzu. Setzen Sie dann den Parameter auf die ausgewählte Option. Sie können zusätzliche Parameter auch durch ein Und-Zeichen (&) trennen.

Um mit einem Schlüsselwort nach einem Fall zu suchen, können Sie das Wort in der Suchleiste ohne Parameter eingeben. Um mit der URL nach einem Schlüsselwort zu suchen, verwenden Sie search als Parameter und setzten Sie ihn auf das Schlüsselwort. Beispiel: search=server.

Nach Fallnummer suchen

Geben Sie Folgendes ein, um Supportfälle anhand der Fallnummer zu durchsuchen:

Abfrage
number:CS1234567
URL
https://cloud.ibm.com/unifiedsupport/cases?number=CS1234567

Mit mehreren Parametern suchen

Sie möchten sowohl neue als auch in Bearbeitung befindliche Supportfälle suchen, die Ergebnisse auf 25 pro Seite begrenzen und die Ergebnisse nach Priorität sortiert anzeigen. Sie wissen auch, dass der Fall, den Sie suchen, nicht auf den ersten Seiten zu finden sein wird, also möchten Sie auf Seite 5 beginnen. Geben Sie die folgende Suchabfrage ein:

Abfrage
status:new,inProgress page:5 pageSize:25 sort:severity
URL
https://cloud.ibm.com/unifiedsupport/cases?status=new&status=inProgress&pageSize=25&sort=severity

Nach gelösten Fällen suchen

Geben Sie die folgende Abfrage ein, um alle gelösten Fälle auf der Basis des Datums der letzten Aktualisierung anzuzeigen:

Abfrage
sort:~updatedAT status:resolved
URL
https://cloud.ibm.com/unifiedsupport/cases?sort=~updatedAT&status=resolved

Erstellen und Verwalten von Fallkennzeichen

Sie können benutzerdefinierte Tags erstellen und verwalten, die an Supportfälle angehängt werden können. Diese Tags helfen bei der Kategorisierung von Fällen nach Service, Vorfall oder einer beliebigen benutzerdefinierten Logik, was die Suche, das Filtern und die Verwaltung großer Mengen von Support-Interaktionen vereinfacht.

Um Tags verwenden zu können, muss das Kundenkonto über eine Premium-Supportstufe verfügen.

Erstellen von Tags in Ihrem Konto

Bevor Sie Fälle kennzeichnen können, müssen Sie Kennzeichnungen auf Kontoebene erstellen. Führen Sie dazu die folgenden Schritte aus:

  1. Navigieren Sie zu Support > Fälle verwalten.
  2. Klicken Sie auf Tags bearbeiten, um so viele Tags wie nötig hinzuzufügen. Diese Tags sind anpassbar und können Dienste, Vorfälle, Teams oder jede andere für Ihr Unternehmen relevante Klassifizierung widerspiegeln.
  3. Klicken Sie auf Speichern.

Jede Markierung muss alphanumerisch und darf nicht länger als 40 Zeichen sein, und Sie können bis zu 20 Markierungen an einen einzelnen Supportfall anhängen.

Verwalten von Tags in Ihrem Konto

Nachdem Sie die Tags erstellt haben, können Sie sie mit einem Fall verknüpfen, indem Sie auf Fall-Tags klicken, und dann über dieselbe Schnittstelle Tags entfernen.

Um Fälle mit bestimmten Tags zu finden, klicken Sie auf einen oder mehrere Tags. Klicken Sie zum Beispiel auf tag100 oder tag100 und tag102, um alle zugehörigen Fälle anzuzeigen.

Es werden nur Fälle angezeigt, die alle ausgewählten Tags enthalten, da die Suchoption eine UND-Bedingung verwendet. Die OR-Filterung wird nicht unterstützt.

Benachrichtigungen für Fälle, die mit einem vertrauenswürdigen Profil eröffnet wurden

Wenn Sie mit einem vertrauenswürdigen Profil arbeiten und einen Support-Fall eröffnen, können Sie zwischen zwei Optionen wählen, um Benachrichtigungen zu erhalten.

Option 1: Benachrichtigungen können an Ihre E-Mail-Adresse gesendet werden.

Option 2: Benachrichtigungen können an die mit dem vertrauenswürdigen Profil verbundene E-Mail-Adresse gesendet werden.

Um die zweite Option zu verwenden, muss eine E-Mail-Adresse mit dem vertrauenswürdigen Profil verknüpft sein, die keine Dienst-ID, Cloud-Ressource oder Computerressource ist.